<?php
/**
 * Based on the Double-sided pages script by Sebastian Rose (http://www.fpdf.org/).
 * Translated to File_PDF class by Javier Mestre 
 */                                                                   

require('File/PDF.php');

class DoubleSided_PDF extends File_PDF
{
	var $doubleSided;    // layout like books?
	var $outerMargin;
	var $innerMargin;
	var $xDelta;         // if double-sided, difference between outer and inner

	function TsPdf($orientation='P',$unit='mm',$format='A4')
	{
		
		$this->doubleSided=false;
		$this->xDelta=0;
		$this->innerMargin=10;
		$this->outerMargin=10;
	}

	function SetDoubleSided($inner=7, $outer=13)
	{
		if($outer != $inner) {
			$this->doubleSided=true;
			$this->outerMargin=$outer;
			$this->innerMargin=$inner;
		}
	}

	function Cell($w,$h=0,$txt='',$border=0,$ln=0,$align='',$fill=0,$link='')
	{
		//Output a cell
		$k=$this->_scale;
		if($this->y+$h>$this->_page_break_trigger && !$this->_in_footer && $this->AcceptPageBreak())
		{
			//Automatic page break
			$x=$this->x;
			$ws=$this->_word_spacing;
			if($ws>0)
			{
				$this->_word_spacing=0;
				$this->_out('0 Tw');
			}
			$this->AddPage($this->_current_orientation);
			$this->x=$x+($this->xDelta);
			if($ws>0)
			{
				$this->_word_spacing=$ws;
				$this->_out(sprintf('%.3f Tw',$ws*$k));
			}
		}
		if($w==0)
			$w=$this->w-$this->_right_margin-$this->x;
		$s='';
		if($fill==1 || $border==1)
		{
			if($fill==1)
				$op=($border==1) ? 'B' : 'f';
			else
				$op='S';
			$s=sprintf('%.2f %.2f %.2f %.2f re %s ',$this->x*$k,($this->h-$this->y)*$k,$w*$k,-$h*$k,$op);
		}
		if(is_string($border))
		{
			$x=$this->x;
			$y=$this->y;
			if(strpos($border,'L')!==false)
				$s.=sprintf('%.2f %.2f m %.2f %.2f l S ',$x*$k,($this->h-$y)*$k,$x*$k,($this->h-($y+$h))*$k);
			if(strpos($border,'T')!==false)
				$s.=sprintf('%.2f %.2f m %.2f %.2f l S ',$x*$k,($this->h-$y)*$k,($x+$w)*$k,($this->h-$y)*$k);
			if(strpos($border,'R')!==false)
				$s.=sprintf('%.2f %.2f m %.2f %.2f l S ',($x+$w)*$k,($this->h-$y)*$k,($x+$w)*$k,($this->h-($y+$h))*$k);
			if(strpos($border,'B')!==false)
				$s.=sprintf('%.2f %.2f m %.2f %.2f l S ',$x*$k,($this->h-($y+$h))*$k,($x+$w)*$k,($this->h-($y+$h))*$k);
		}
		if($txt!=='')
		{
			if($align=='R')
				$dx=$w-$this->_cell_margin-$this->GetStringWidth($txt);
			elseif($align=='C')
				$dx=($w-$this->GetStringWidth($txt))/2;
			else
				$dx=$this->_cell_margin;
			if($this->_color_flag)
				$s.='q '.$this->TextColor.' ';
			$txt2=str_replace(')','\\)',str_replace('(','\\(',str_replace('\\','\\\\',$txt)));
			$s.=sprintf('BT %.2f %.2f Td (%s) Tj ET',($this->x+$dx)*$k,($this->h-($this->y+.5*$h+.3*$this->_font_size))*$k,$txt2);
			if($this->_underline)
				$s.=' '.$this->_dounderline($this->x+$dx,$this->y+.5*$h+.3*$this->_font_size,$txt);
			if($this->_color_flag)
				$s.=' Q';
			if($link)
				$this->Link($this->x+$dx,$this->y+.5*$h-.5*$this->_font_size,$this->GetStringWidth($txt),$this->_font_size,$link);
		}
		if($s)
			$this->_out($s);
		$this->lasth=$h;
		if($ln>0)
		{
			//Go to next line
			$this->y+=$h;
			if($ln==1)
				$this->x=$this->_left_margin;
		}
		else
			$this->x+=$w;
	}

	function _beginpage($orientation)
	{
		parent::_beginpage($orientation);
		if ( $this->doubleSided ) {
			if( $this->_page % 2 == 0 ) {
				$this->xDelta=$this->outerMargin - $this->innerMargin;
				$this->SetLeftMargin($this->outerMargin);
				$this->SetRightMargin($this->innerMargin);
			} else {
				$this->xDelta=$this->innerMargin - $this->outerMargin;
				$this->SetLeftMargin($this->innerMargin);
				$this->SetRightMargin($this->outerMargin);
			}
			$this->x=$this->_left_margin;
			$this->y=$this->_top_margin;
		}
	}
}
?>
